@@ -1794,7 +1794,7 @@ classdef duration
 ################################################################################
 ##                             Available Methods                              ##
 ##                                                                            ##
-## 'end'              'subsref'          'subsasgn'         'subset'          ##
+## 'end'              'subsref'          'subsasgn'                           ##
 ##                                                                            ##
 ################################################################################
 
@@ -1898,10 +1898,6 @@ classdef duration
       out.Days = this.Days(varargin{:});
     endfunction
 
-  endmethods
-
-  methods (Access = private)
-
     ## Fix floating point precision near zero
     function this = fix_zero_precision (this)
       this.Days(this.Days > -1e-15 & this.Days < 1e-15) = 0;
